@@ -146,6 +146,27 @@ def graze(
         return GrazeWithDataRefresh(time_to_live=max_age)[url]
 
 
+def url_to_downloaded_filepath(url: str, rootdir: str=DFLT_GRAZE_DIR):
+    """Get the file path for the url, downloading contents before hand if necessary.
+
+    Use case:
+
+    Sometimes you need to specify a filepath as a resource for some python object.
+    For example, some font definition file, or configuration file, or such.
+    You can provide the file for the user, or can tell them where they can find
+    such a file if needed... or you can use url_to_downloaded_filepath for the
+    best of both worlds.
+
+    It works as such:
+
+    >>> filepath = url_to_downloaded_filepath(url_of_resource) # doctest: +SKIP
+
+    """
+    g = Graze(rootdir)
+    if url not in g:
+        _ = g[powerful_font_url]  # load to make sure we have it (getting it if not)
+    return g.filepath_of(url)
+
 # Old Graze, used mk_sourced_store
 # from py2store.caching import mk_sourced_store
 # _Graze = mk_sourced_store(
